@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import hashlib
 import json
+import locale
 import logging
 import os
 import shutil
@@ -34,7 +35,6 @@ import botocore.exceptions
 import docker
 import docker.types
 import formic
-from docker.models.containers import Container
 from docker.models.images import Image
 from troposphere.awslambda import Code
 from typing_extensions import Literal, TypedDict
@@ -217,7 +217,8 @@ def _calculate_hash(files: Iterable[str], root: str) -> str:
         file_path = os.path.join(root, file_name)
         file_hash.update((file_name + "\0").encode())
         with open(file_path, "rb") as file_:
-            for chunk in iter(lambda: file_.read(4096), ""):  # pylint: disable=W
+            # pylint: disable=cell-var-from-loop
+            for chunk in iter(lambda: file_.read(4096), ""):
                 if not chunk:
                     break
                 file_hash.update(chunk)
@@ -445,12 +446,12 @@ def dockerized_pip(
         # the response can be either a tuple of (Image, Generator[Dict[str, str]])
         # or just Image depending on API version.
         if isinstance(response, tuple):
-            docker_image = cast(str, response[0].id)
+            docker_image = response[0].id
             for log_msg in response[1]:
                 if log_msg.get("stream"):
                     LOGGER.info(log_msg["stream"].strip("\n"))
         else:
-            docker_image = cast(str, response.id)
+            docker_image = response.id
         LOGGER.info('docker image "%s" created', docker_image)
     if runtime:
         if runtime not in SUPPORTED_RUNTIMES:
@@ -477,23 +478,18 @@ def dockerized_pip(
     if python_dontwritebytecode:
         docker_run_args["environment"] = "1"
 
-    container = cast(
-        Container,
-        client.containers.run(
-            image=docker_image,
-            command=["/bin/sh", "-c", pip_cmd],
-            auto_remove=True,
-            detach=True,
-            mounts=[work_dir_mount],
-            **docker_run_args,
-        ),
+    container = client.containers.run(
+        image=cast(str, docker_image),
+        command=["/bin/sh", "-c", pip_cmd],
+        auto_remove=True,
+        detach=True,
+        mounts=[work_dir_mount],
+        **docker_run_args,
     )
 
     # 'stream' creates a blocking generator that allows for real-time logs.
     # this loop ends when the container 'auto_remove's itself.
-    for log in cast(
-        Iterator[bytes], container.logs(stdout=True, stderr=True, stream=True, tail=0)
-    ):
+    for log in container.logs(stdout=True, stderr=True, stream=True, tail=0):
         # without strip there are a bunch blank lines in the output
         LOGGER.info(log.decode().strip())
 
@@ -629,7 +625,10 @@ def _zip_package(  # pylint: disable=too-many-locals,too-many-statements
                     '   runpy.run_module("pip", run_name="__main__")\n',
                 ]
             )
-            tmp_script.write_text(script_contents)
+            tmp_script.write_text(
+                script_contents,
+                encoding=locale.getpreferredencoding(do_setlocale=False),
+            )
             cmd = [sys.executable, "run-python", str(tmp_script)]
         else:
             if not _pip_has_no_color_option(pip_cmd[0]):
@@ -665,7 +664,7 @@ def _zip_package(  # pylint: disable=too-many-locals,too-many-statements
     if sys.version_info.major < 3:
         remove_error = OSError
     else:
-        remove_error = PermissionError  # noqa pylint: disable=E
+        remove_error = PermissionError
     try:
         tmpdir.cleanup()
     except remove_error:
@@ -1071,6 +1070,11 @@ def upload_lambda_functions(context: CfnginContext, provider: Provider, **kwargs
                     )
 
     """
+    LOGGER.warning(
+        "%s is deprecated and will be removed in a future release - "
+        "see documentation for replacement",
+        __name__,
+    )
     # TODO add better handling for misconfiguration (e.g. forgetting function names)
     # TODO support defining dockerize_pip options at the top level of args
     custom_bucket = cast(str, kwargs.get("bucket", ""))
