@@ -6,14 +6,14 @@ import operator
 import re
 from typing import TYPE_CHECKING, Any, Dict
 
+from typing_extensions import Final, Literal
+
 from ....lookups.handlers.base import LookupHandler
 from ...utils import read_value_from_path
 
 if TYPE_CHECKING:
     from ....context import CfnginContext
 
-TYPE_NAME = "ami"
-
 
 class ImageNotFound(Exception):
     """Image not found."""
@@ -23,15 +23,17 @@ class ImageNotFound(Exception):
     def __init__(self, search_string: str) -> None:
         """Instantiate class."""
         self.search_string = search_string
-        message = ("Unable to find ec2 image with search string: {}").format(
-            search_string
+        super().__init__(
+            f"Unable to find ec2 image with search string: {search_string}"
         )
-        super().__init__(message)
 
 
 class AmiLookup(LookupHandler):
     """AMI lookup."""
 
+    TYPE_NAME: Final[Literal["ami"]] = "ami"
+    """Name that the Lookup is registered as."""
+
     @classmethod
     def handle(  # pylint: disable=arguments-differ
         cls, value: str, context: CfnginContext, *__args: Any, **__kwargs: Any
