@@ -11,13 +11,11 @@ from typing import Any, Callable, Dict, List, Mapping, Sequence, Union, overload
 
 import yaml
 from troposphere import Base64, GenericHelperFn
-from typing_extensions import Literal
+from typing_extensions import Final, Literal
 
 from ....lookups.handlers.base import LookupHandler
 from ...utils import read_value_from_path
 
-TYPE_NAME = "file"
-
 _PARAMETER_PATTERN = re.compile(r"{{([::|\w]+)}}")
 
 ParameterizedObjectTypeDef = Union[bytes, str, Mapping[str, Any], Sequence[Any], Any]
@@ -31,6 +29,9 @@ ParameterizedObjectReturnTypeDef = Union[
 class FileLookup(LookupHandler):
     """File lookup."""
 
+    TYPE_NAME: Final[Literal["file"]] = "file"
+    """Name that the Lookup is registered as."""
+
     @classmethod
     def handle(cls, value: str, **_: Any) -> Any:
         r"""Translate a filename into the file contents.
