@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import copy
+import locale
 import logging
 import os
 import re
@@ -379,7 +380,9 @@ def read_value_from_path(value: str, *, root_path: Optional[Path] = None) -> str
             else:
                 read_path = root_path.parent / path
         if read_path.is_file():
-            return read_path.read_text()
+            return read_path.read_text(
+                encoding=locale.getpreferredencoding(do_setlocale=False)
+            )
         if read_path.is_dir():
             raise ValueError(
                 f"path must lead to a file not directory: {read_path.absolute()}"
@@ -829,8 +832,7 @@ class SourceProcessor:
         """
         LOGGER.debug("getting commit ID from repo: %s", " ".join(uri))
         ls_remote_output = subprocess.check_output(["git", "ls-remote", uri, ref])
-        # incorrectly detected - https://github.com/PyCQA/pylint/issues/3045
-        if b"\t" in ls_remote_output:  # pylint: disable=unsupported-membership-test
+        if b"\t" in ls_remote_output:
             commit_id = ls_remote_output.split(b"\t", maxsplit=1)[0]
             LOGGER.debug("matching commit id found: %s", commit_id)
             return commit_id.decode()
