@@ -1,5 +1,4 @@
 """CFNgin config."""
-# pylint: disable=no-self-argument,no-self-use
 from __future__ import annotations
 
 import logging
@@ -23,7 +22,7 @@ from typing import (
 import yaml
 
 from ..cfngin import exceptions
-from ..cfngin.lookups import register_lookup_handler
+from ..cfngin.lookups.registry import register_lookup_handler
 from ..cfngin.utils import SourceProcessor
 from ..exceptions import ConfigNotFound
 from ..utils import merge_dicts
@@ -263,7 +262,7 @@ class CfnginConfig(BaseConfig):
         return result
 
     @classmethod
-    def parse_file(  # pylint: disable=arguments-differ
+    def parse_file(
         cls,
         *,
         path: Optional[Path] = None,
