@@ -3,7 +3,9 @@ from __future__ import annotations
 
 import base64
 import logging
-from typing import TYPE_CHECKING, Any, Union  # pylint: disable=W
+from typing import TYPE_CHECKING, Any, Union
+
+from typing_extensions import Final, Literal
 
 from ...lookups.handlers.base import LookupHandler
 
@@ -14,12 +16,13 @@ if TYPE_CHECKING:
 
 LOGGER = logging.getLogger(__name__)
 
-TYPE_NAME = "ecr"
-
 
 class EcrLookup(LookupHandler):
     """ECR Lookup."""
 
+    TYPE_NAME: Final[Literal["ecr"]] = "ecr"
+    """Name that the Lookup is registered as."""
+
     @staticmethod
     def get_login_password(client: ECRClient) -> str:
         """Get a password to login to ECR registry."""
